# Changelog

## [0.1.1a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/0.1.1a5) (2024-02-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a4...0.1.1a5)

**Implemented enhancements:**

- feat/refresh\_oauth\_token [\#65](https://github.com/OpenVoiceOS/ovos-backend-client/pull/65) ([JarbasAl](https://github.com/JarbasAl))

**Fixed bugs:**

- OAuthApplicationDatabase update\_application infinite recursion [\#60](https://github.com/OpenVoiceOS/ovos-backend-client/issues/60)

## [V0.1.1a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a4) (2024-01-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a3...V0.1.1a4)

**Fixed bugs:**

- Database: Fix update\_application\(\) method [\#62](https://github.com/OpenVoiceOS/ovos-backend-client/pull/62) ([forslund](https://github.com/forslund))

## [V0.1.1a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a3) (2024-01-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a2...V0.1.1a3)

**Fixed bugs:**

- Fix path errors in Database init [\#58](https://github.com/OpenVoiceOS/ovos-backend-client/pull/58) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.1.1a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a2) (2023-12-30)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.1a1...V0.1.1a2)

**Fixed bugs:**

- Fix location config reference [\#57](https://github.com/OpenVoiceOS/ovos-backend-client/pull/57) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.1.1a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.1a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0...V0.1.1a1)

**Merged pull requests:**

- packaging/update\_imports [\#56](https://github.com/OpenVoiceOS/ovos-backend-client/pull/56) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
